<?php

/**
 * Inline Styles in WP Head
 * @return void 
 */
function swa_inline_style() {
	$swa = swa();
	if( ! $swa->has_ad_position('top') && ! $swa->has_ad_position('bottom') ) {
		return;
	}
	
	?>
	<style>
		body.swa_ad_top {
			padding-top:50px; 
		}
		body.swa_ad_bottom {
			padding-bottom: 50px;
		}

		.swa_ad_top .swa_ad_top {
			position: absolute;
			top:0;
		}

		.swa_ad_bottom .swa_ad_bottom {
			position: fixed;
			bottom:0;
			top: auto;
			z-index:999;
		}

		.swa_ad {
			left:0;
			width: 100%;
			height: 50px;
			line-height: 50px;
			text-align: center;
			background-color:#333;
			color:white;
			overflow: hidden;
		}

		.swa_ad img {
			max-height: 50px;
			width: auto;
		}

		.swa_ad p {
			display:inline-block;
			margin-left: 1em;
			color:white;
		}

		.admin-bar.swa_ad_top .swa_ad_top{
			top: 32px;
		}

		@media screen and (max-width: 782px) {
			.admin-bar.swa_ad_top .swa_ad{
				top: 46px;
			}
		}
	</style> 
<?php
}

/**
 * Create Ads Array we will store and use
 * @param  array $ads Array of posts
 * @return mixed      
 */
function swa_create_ads_array( $ads ){
	$ads_array = array();
	$ads_array['top'] = array();
	$ads_array['bottom'] = array();

	foreach ( $ads as $ad ) {
		$ad_meta = get_post_meta( $ad->ID, 'swa_info', true );

		$new_ad = array(
			'id' => $ad->ID,
			'post_title' => $ad->post_title,
			'link' => $ad_meta['link'],
			'image' => get_the_post_thumbnail( $ad->ID, 'full' )
		);

		$position = $ad_meta['position'];
		$ads_array[ $position ][] = $new_ad;
	}

	if( count( $ads_array['top'] ) == 0 && count( $ads_array['bottom'] ) == 0 ) {
		return false;
	}

	return $ads_array;
}

/**
 * Get Ads from cache or from the database
 * @return mixed 
 */
function swa_get_ads(){
	if ( false === ( $ads = get_transient( 'swa_ads' ) ) ) {
	   
	  	/**
	  	 * The WordPress Query class.
	  	 * @link http://codex.wordpress.org/Function_Reference/WP_Query
	  	 *
	  	 */
	  	$args = array(
	  		
	  		//Type & Status Parameters
	  		'post_type'   => 'swa',
	  		'post_status' => 'publish',
	  		 
	  		
	  		//Pagination Parameters
	  		'posts_per_page'         => 100
	  		
	  	);
	  
	    $ads_from_db = get_posts( $args );

	    $ads = swa_create_ads_array( $ads_from_db );
	  
	  	set_transient( 'swa_ads', $ads );
	}

	$swa = swa();
	$swa->set_ads( $ads );
	return $ads;
}

/**
 * Add body classes for position on which ads will be displayed
 * @return [type] [description]
 */
function swa_add_body_classes() {

	$swa = swa();

	if( $swa->has_ad_position( 'top' ) ) {
		add_filter('body_class', 'swa_add_body_top_class' );
	}

	if( $swa->has_ad_position( 'bottom' ) ) {
		add_filter('body_class', 'swa_add_body_bottom_class' );
	}
}

/**
 * Filter function to add the class for top
 * @param  array $classes Array of classes that will be added to body
 * @return array          
 */
function swa_add_body_top_class( $classes ) {
	$classes[] = 'swa_ad_top';
	return $classes;
}

/**
 * Filter function to add the class for bottom 
 * @param  array $classes Array of classes that will be added to body
 * @return array          
 */
function swa_add_body_bottom_class( $classes ) {
	$classes[] = 'swa_ad_bottom';
	return $classes;
}

/**
 * Display the ads, one random ad per position
 * @return void 
 */
function swa_display_ads() {
	$swa = swa();
	$ads = $swa->get_ads();

	if( $ads ) {
		$top_ads = $ads['top'];
		$bottom_ads = $ads['bottom'];

		if( count( $top_ads ) > 0 ) {
			$random_top_ad = array_rand( $top_ads );
			$the_top_ad = $top_ads[ $random_top_ad ];
			swa_set_impressions( $the_top_ad );
			swa_render_ad( $the_top_ad, 'top' );
		}

		if( count( $bottom_ads ) > 0 ) {
			$random_bottom_ad = array_rand( $bottom_ads );
			$the_bottom_ad = $bottom_ads[ $random_bottom_ad ];
			swa_set_impressions( $the_bottom_ad );
			swa_render_ad( $the_bottom_ad, 'bottom' );
		}
	}

}

/**
 * Rendering function for the Ad
 * @param  array 	$ad_array Definition array of Ad
 * @param  string 	$position 
 * @return void           
 */
function swa_render_ad( $ad_array, $position ) {
	$swa_ad_class = 'swa_ad_top';
	if( $position == 'bottom' ) {
		$swa_ad_class = 'swa_ad_bottom';
	}

	$link = $ad_array['link'];
	if( strpos( $link, 'http' ) === false ) {
		$link = 'http://' . $link;
	}
	echo '<div class="swa_ad ' . $swa_ad_class . '">';
		echo '<a data-id="' . $ad_array['id'] . '" target="_blank" href="' . $link . '">';
			echo $ad_array['image'];
			echo '<p>' . $ad_array['post_title'] . '</p>';
		echo '</a>';
	echo '</div>';
}

/**
 * Enqueueing scripts on the front
 * @return void 
 */
function swa_enqueue_scripts(){

	$swa = swa();
	if( ! $swa->has_ad_position('top') && ! $swa->has_ad_position('bottom') ) {
		return;
	}

	wp_register_script( 'swa-front-js', SWA_URI . 'assets/js/swa.js', array('jquery'), '', true );
	
	$script_array = array(
		'ajax_url' => admin_url( 'admin-ajax.php' )
	);

	wp_localize_script( 'swa-front-js', 'swa', $script_array );

	wp_enqueue_script( 'swa-front-js' );

}

/**
 * Set impressions for Ad
 * @param  array $ad_array 
 * @return void           
 */
function swa_set_impressions( $ad_array ) {
	$ad_id = $ad_array['id'];
	$impressions =  (int) get_post_meta( $ad_id, '_impressions', true );
	if( ! $impressions ) {
		$impressions = 0;
	}
	$impressions++;
	update_post_meta( $ad_id, '_impressions', $impressions );
}